@@ -5,20 +5,19 @@ from typing import List, Optional, Union
 
 import numpy as np
 import pandas as pd
-from sklearn.utils.validation import check_is_fitted
 
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
+from feature_engine._docstrings.init_parameters import (
+    _ignore_format_docstring,
+    _variables_categorical_docstring,
+)
 from feature_engine._docstrings.methods import _fit_transform_docstring
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine.dataframe_checks import check_X
-from feature_engine.encoding._docstrings import (
-    _ignore_format_docstring,
-    _variables_docstring,
-)
+from feature_engine.dataframe_checks import _check_contains_na, check_X
 from feature_engine.encoding.base_encoder import (
     CategoricalInitMixin,
     CategoricalMethodsMixin,
@@ -27,7 +26,7 @@ from feature_engine.encoding.base_encoder import (
 
 @Substitution(
     ignore_format=_ignore_format_docstring,
-    variables=_variables_docstring,
+    variables=_variables_categorical_docstring,
     variables_=_variables_attribute_docstring,
     feature_names_in_=_feature_names_in_docstring,
     n_features_in_=_n_features_in_docstring,
@@ -185,7 +184,7 @@ class OneHotEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         """
 
         X = check_X(X)
-        self._check_or_select_variables(X)
+        self._fit(X)
         self._get_feature_names_in(X)
 
         self.encoder_dict_ = {}
@@ -224,8 +223,6 @@ class OneHotEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
                 category = X[var].unique()[0]
                 self.encoder_dict_[var] = [category]
 
-        self._check_encoding_dictionary()
-
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -247,11 +244,12 @@ class OneHotEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
         X = self._check_transform_input_and_state(X)
 
+        # check if dataset contains na
+        _check_contains_na(X, self.variables_)
+
         for feature in self.variables_:
             for category in self.encoder_dict_[feature]:
-                X[str(feature) + "_" + str(category)] = np.where(
-                    X[feature] == category, 1, 0
-                )
+                X[f"{feature}_{category}"] = np.where(X[feature] == category, 1, 0)
 
         # drop the original non-encoded variables.
         X.drop(labels=self.variables_, axis=1, inplace=True)
@@ -260,47 +258,22 @@ class OneHotEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
     def inverse_transform(self, X: pd.DataFrame):
         """inverse_transform is not implemented for this transformer."""
-        return self
+        raise NotImplementedError(
+            "inverse_transform is not implemented for this transformer."
+        )
 
-    def get_feature_names_out(self, input_features: Optional[List] = None) -> List:
-        """Get output feature names for transformation.
-
-        Parameters
-        ----------
-        input_features: list, default=None
-            Input features. If `input_features` is `None`, then the names of all the
-            variables in the transformed dataset (original + new variables) is returned.
-            Alternatively, only the names for the binary variables derived from
-            input_features will be returned.
-
-        Returns
-        -------
-        feature_names_out: list
-            The feature names.
-        """
-        check_is_fitted(self)
-
-        if input_features is None:
-            input_features_ = self.feature_names_in_
-        else:
-            if not isinstance(input_features, list):
-                raise ValueError(
-                    f"input_features must be a list. Got {input_features} instead."
-                )
-            if any(f for f in input_features if f not in self.feature_names_in_):
-                raise ValueError(
-                    "Some of the features requested were not seen during training."
-                )
-            input_features_ = input_features
-
-        # the features not encoded
-        feature_names = [f for f in input_features_ if f not in self.variables_]
-
-        # the encoded features
-        encoded = [f for f in input_features_ if f in self.variables_]
-
-        for feature in encoded:
+    def _get_new_features_name(self) -> List:
+        """Return names of the created features."""
+        feature_names = []
+        for feature in self.variables_:
             for category in self.encoder_dict_[feature]:
-                feature_names.append(str(feature) + "_" + str(category))
+                feature_names.append(f"{feature}_{category}")
+
+        return feature_names
+
+    def _add_new_feature_names(self, feature_names) -> List:
+        """Adds new features to df columns, and removes categoricals."""
+        feature_names = feature_names + self._get_new_features_name()
+        feature_names = [f for f in feature_names if f not in self.variables_]
 
         return feature_names
