@@ -12,6 +12,7 @@ from .shuffle_features import SelectByShuffling
 from .single_feature_performance import SelectBySingleFeaturePerformance
 from .smart_correlation_selection import SmartCorrelatedSelection
 from .target_mean_selection import SelectByTargetMeanPerformance
+from .information_value import SelectByInformationValue
 
 __all__ = [
     "DropFeatures",
@@ -25,4 +26,5 @@ __all__ = [
     "RecursiveFeatureAddition",
     "RecursiveFeatureElimination",
     "SelectByTargetMeanPerformance",
+    "SelectByInformationValue",
 ]
