@@ -2,27 +2,30 @@ from typing import List, Union
 
 import pandas as pd
 
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine._variable_handling.init_parameter_checks import (
+    _check_init_parameter_variables,
+)
+from feature_engine._variable_handling.variable_type_selection import (
+    _find_or_check_numerical_variables,
+)
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
     _check_contains_na,
     check_X,
 )
-from feature_engine._docstrings.methods import _fit_transform_docstring
-from feature_engine._docstrings.fit_attributes import (
-    _feature_names_in_docstring,
-    _n_features_in_docstring,
-)
-from feature_engine._docstrings.substitute import Substitution
 from feature_engine.selection._docstring import (
+    _get_support_docstring,
     _missing_values_docstring,
     _variables_attribute_docstring,
     _variables_numerical_docstring,
 )
 from feature_engine.selection.base_selector import BaseSelector
-from feature_engine.variable_manipulation import (
-    _check_input_parameter_variables,
-    _find_or_check_numerical_variables,
-)
 
 Variables = Union[None, int, str, List[Union[str, int]]]
 
@@ -35,6 +38,7 @@ Variables = Union[None, int, str, List[Union[str, int]]]
     feature_names_in_=_feature_names_in_docstring,
     n_features_in_=_n_features_in_docstring,
     fit_transform=_fit_transform_docstring,
+    get_support=_get_support_docstring,
 )
 class DropCorrelatedFeatures(BaseSelector):
     """
@@ -91,6 +95,8 @@ class DropCorrelatedFeatures(BaseSelector):
 
     {fit_transform}
 
+    {get_support}
+
     transform:
         Remove correlated features.
 
@@ -122,7 +128,7 @@ class DropCorrelatedFeatures(BaseSelector):
 
         super().__init__(confirm_variables)
 
-        self.variables = _check_input_parameter_variables(variables)
+        self.variables = _check_init_parameter_variables(variables)
         self.method = method
         self.threshold = threshold
         self.missing_values = missing_values
