@@ -7,20 +7,22 @@ import pandas as pd
 import scipy.stats as stats
 from scipy.special import inv_boxcox
 
-from feature_engine._docstrings.class_inputs import _variables_numerical_docstring
+from feature_engine._base_transformers.base_numerical import BaseNumericalTransformer
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
+from feature_engine._docstrings.init_parameters import _variables_numerical_docstring
 from feature_engine._docstrings.methods import (
     _fit_transform_docstring,
     _inverse_transform_docstring,
 )
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine.base_transformers import BaseNumericalTransformer
+from feature_engine._variable_handling.init_parameter_checks import (
+    _check_init_parameter_variables,
+)
 from feature_engine.tags import _return_tags
-from feature_engine.variable_manipulation import _check_input_parameter_variables
 
 
 @Substitution(
@@ -95,7 +97,7 @@ class BoxCoxTransformer(BaseNumericalTransformer):
         self, variables: Union[None, int, str, List[Union[str, int]]] = None
     ) -> None:
 
-        self.variables = _check_input_parameter_variables(variables)
+        self.variables = _check_init_parameter_variables(variables)
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -112,7 +114,7 @@ class BoxCoxTransformer(BaseNumericalTransformer):
         """
 
         # check input dataframe
-        X = super()._fit_from_varlist(X)
+        X = super().fit(X)
 
         self.lambda_dict_ = {}
 
@@ -139,6 +141,10 @@ class BoxCoxTransformer(BaseNumericalTransformer):
         # check input dataframe and if class was fitted
         X = super().transform(X)
 
+        # check contains zero or negative values
+        if (X[self.variables_] <= 0).any().any():
+            raise ValueError("Data must be positive.")
+
         # transform
         for feature in self.variables_:
             X[feature] = stats.boxcox(X[feature], lmbda=self.lambda_dict_[feature])
