@@ -1,6 +1,5 @@
 import pandas as pd
 import pytest
-
 from sklearn.pipeline import Pipeline
 
 from feature_engine.encoding import OneHotEncoder
@@ -398,7 +397,7 @@ def test_encode_into_top_categories_plus_drop_binary(df_enc_binary):
 
 def test_get_feature_names_out(df_enc_binary):
     original_features = ["var_num"]
-    input_features = ["var_A", "var_B", "var_C", "var_D"]
+    input_features = df_enc_binary.columns
 
     tr = OneHotEncoder()
     tr.fit(df_enc_binary)
@@ -416,10 +415,10 @@ def test_get_feature_names_out(df_enc_binary):
         "var_D_EHE",
     ]
 
-    assert tr.get_feature_names_out(input_features=None) == original_features + out
-    assert tr.get_feature_names_out(input_features=input_features) == out
-    assert tr.get_feature_names_out(input_features=input_features[0:2]) == out[0:6]
-    assert tr.get_feature_names_out(input_features=[input_features[0]]) == out[0:3]
+    feat_out = original_features + out
+
+    assert tr.get_feature_names_out(input_features=None) == feat_out
+    assert tr.get_feature_names_out(input_features=input_features) == feat_out
 
     tr = OneHotEncoder(drop_last=True)
     tr.fit(df_enc_binary)
@@ -432,11 +431,10 @@ def test_get_feature_names_out(df_enc_binary):
         "var_C_AHA",
         "var_D_OHO",
     ]
+    feat_out = original_features + out
 
-    assert tr.get_feature_names_out(input_features=None) == original_features + out
-    assert tr.get_feature_names_out(input_features=input_features) == out
-    assert tr.get_feature_names_out(input_features=input_features[0:2]) == out[0:4]
-    assert tr.get_feature_names_out(input_features=[input_features[0]]) == out[0:2]
+    assert tr.get_feature_names_out(input_features=None) == feat_out
+    assert tr.get_feature_names_out(input_features=input_features) == feat_out
 
     tr = OneHotEncoder(drop_last_binary=True)
     tr.fit(df_enc_binary)
@@ -451,21 +449,19 @@ def test_get_feature_names_out(df_enc_binary):
         "var_C_AHA",
         "var_D_OHO",
     ]
+    feat_out = original_features + out
 
-    assert tr.get_feature_names_out(input_features=None) == original_features + out
-    assert tr.get_feature_names_out(input_features=input_features) == out
-    assert tr.get_feature_names_out(input_features=[input_features[0]]) == out[0:3]
-    assert tr.get_feature_names_out(input_features=[input_features[3]]) == [out[-1]]
+    assert tr.get_feature_names_out(input_features=None) == feat_out
+    assert tr.get_feature_names_out(input_features=input_features) == feat_out
 
     tr = OneHotEncoder(top_categories=1)
     tr.fit(df_enc_binary)
 
     out = ["var_A_B", "var_B_A", "var_C_AHA", "var_D_EHE"]
+    feat_out = original_features + out
 
-    assert tr.get_feature_names_out(input_features=None) == original_features + out
-    assert tr.get_feature_names_out(input_features=input_features) == out
-    assert tr.get_feature_names_out(input_features=input_features[0:2]) == out[0:2]
-    assert tr.get_feature_names_out(input_features=[input_features[3]]) == [out[3]]
+    assert tr.get_feature_names_out(input_features=None) == feat_out
+    assert tr.get_feature_names_out(input_features=input_features) == feat_out
 
     with pytest.raises(ValueError):
         tr.get_feature_names_out("var_A")
@@ -476,7 +472,7 @@ def test_get_feature_names_out(df_enc_binary):
 
 def test_get_feature_names_out_from_pipeline(df_enc_binary):
     original_features = ["var_num"]
-    input_features = ["var_A", "var_B", "var_C", "var_D"]
+    input_features = df_enc_binary.columns
 
     tr = Pipeline([("transformer", OneHotEncoder())])
     tr.fit(df_enc_binary)
@@ -493,8 +489,19 @@ def test_get_feature_names_out_from_pipeline(df_enc_binary):
         "var_D_OHO",
         "var_D_EHE",
     ]
+    feat_out = original_features + out
 
-    assert tr.get_feature_names_out(input_features=None) == original_features + out
-    assert tr.get_feature_names_out(input_features=input_features) == out
-    assert tr.get_feature_names_out(input_features=input_features[0:2]) == out[0:6]
-    assert tr.get_feature_names_out(input_features=[input_features[0]]) == out[0:3]
+    assert tr.get_feature_names_out(input_features=None) == feat_out
+    assert tr.get_feature_names_out(input_features=input_features) == feat_out
+
+
+@pytest.mark.parametrize("drop_binary", ["hello", ["auto"], -1, 100, 0.5])
+def test_raises_error_when_not_allowed_smoothing_param_in_init(drop_binary):
+    with pytest.raises(ValueError):
+        OneHotEncoder(drop_last_binary=drop_binary)
+
+
+def test_inverse_transform_raises_not_implemented_error(df_enc_binary):
+    enc = OneHotEncoder().fit(df_enc_binary)
+    with pytest.raises(NotImplementedError):
+        enc.inverse_transform(df_enc_binary)
