@@ -14,6 +14,7 @@ from feature_engine.selection import (
     SelectBySingleFeaturePerformance,
     SelectByTargetMeanPerformance,
     SmartCorrelatedSelection,
+    SelectByInformationValue,
 )
 from tests.estimator_checks.estimator_checks import check_feature_engine_estimator
 from tests.estimator_checks.init_params_triggered_functionality_checks import (
@@ -35,6 +36,7 @@ _estimators = [
     SelectBySingleFeaturePerformance(estimator=_logreg, scoring="accuracy"),
     RecursiveFeatureAddition(estimator=_logreg, scoring="accuracy"),
     RecursiveFeatureElimination(estimator=_logreg, scoring="accuracy", threshold=-100),
+    SelectByInformationValue(bins=2),
 ]
 
 _multivariate_estimators = [
@@ -52,8 +54,9 @@ _univariate_estimators = [
     DropHighPSIFeatures(bins=5),
     SelectByTargetMeanPerformance(bins=3, regression=False, threshold=0),
     SelectBySingleFeaturePerformance(
-        estimator=_logreg, scoring="accuracy", threshold=0
+        estimator=_logreg, scoring="accuracy", threshold=0,
     ),
+    SelectByInformationValue(bins=2),
 ]
 
 _model_based_estimators = [
