@@ -4,15 +4,13 @@ import numpy as np
 import pandas as pd
 import pytest
 from sklearn.ensemble import RandomForestClassifier
-from sklearn.exceptions import NotFittedError
 from sklearn.linear_model import LinearRegression
-from sklearn.model_selection import KFold, StratifiedKFold
 from sklearn.tree import DecisionTreeRegressor
 
 from feature_engine.selection import SelectBySingleFeaturePerformance
 
 
-def test_default_parameters(df_test):
+def test_sel_with_default_parameters(df_test):
     X, y = df_test
     sel = SelectBySingleFeaturePerformance(
         RandomForestClassifier(random_state=1), threshold=0.5
@@ -24,25 +22,10 @@ def test_default_parameters(df_test):
     Xtransformed.drop(columns=["var_3", "var_10"], inplace=True)
 
     # test init params
-    assert sel.variables is None
     assert sel.threshold == 0.5
     assert sel.cv == 3
     assert sel.scoring == "roc_auc"
     # test fit attrs
-    assert sel.variables_ == [
-        "var_0",
-        "var_1",
-        "var_2",
-        "var_3",
-        "var_4",
-        "var_5",
-        "var_6",
-        "var_7",
-        "var_8",
-        "var_9",
-        "var_10",
-        "var_11",
-    ]
     assert sel.features_to_drop_ == ["var_3", "var_10"]
     assert sel.feature_performance_ == {
         "var_0": 0.5957642619540211,
@@ -88,11 +71,9 @@ def test_regression_cv_3_and_r2(load_diabetes_dataset):
 
     # test init params
     assert sel.cv == 3
-    assert sel.variables is None
     assert sel.scoring == "r2"
     assert sel.threshold == 0.01
     # fit params
-    assert sel.variables_ == list(X.columns)
     assert sel.features_to_drop_ == [1]
     assert all(
         np.round(sel.feature_performance_[f], 3) == performance_dict[f]
@@ -122,23 +103,24 @@ def test_regression_cv_2_and_mse(load_diabetes_dataset):
 
     # test init params
     assert sel.cv == 2
-    assert sel.variables is None
     assert sel.scoring == "neg_mean_squared_error"
     assert sel.threshold == -6000
     # fit params
-    assert sel.variables_ == list(X.columns)
     assert sel.features_to_drop_ == [0, 2, 3, 4, 5, 6, 8, 9]
-    assert sel.feature_performance_ == {
-        0: -7657.154138192973,
-        1: -5966.662211695372,
-        2: -6613.779604700854,
-        3: -6502.621725718592,
-        4: -9415.586278197177,
-        5: -11760.999622926094,
-        6: -6592.584431571728,
-        7: -5270.563893676307,
-        8: -7641.414795123177,
-        9: -6287.557824391035,
+    rounded_perfs = {
+        key: round(sel.feature_performance_[key], 2) for key in sel.feature_performance_
+    }
+    assert rounded_perfs == {
+        0: -7657.15,
+        1: -5966.66,
+        2: -6613.78,
+        3: -6488.93,
+        4: -9415.59,
+        5: -11761.0,
+        6: -6592.58,
+        7: -5270.56,
+        8: -7547.2,
+        9: -6287.56,
     }
     # test transform output
     print(sel.transform(X))
@@ -157,13 +139,6 @@ def test_raises_warning_if_no_feature_selected(load_diabetes_dataset):
         warnings.warn(sel.fit(X, y), UserWarning)
 
 
-def test_non_fitted_error(df_test):
-    # when fit is not called prior to transform
-    with pytest.raises(NotFittedError):
-        sel = SelectBySingleFeaturePerformance(RandomForestClassifier(random_state=1))
-        sel.transform(df_test)
-
-
 def test_raises_threshold_error():
     with pytest.raises(ValueError):
         SelectBySingleFeaturePerformance(
@@ -203,25 +178,10 @@ def test_automatic_variable_selection(df_test):
     Xtransformed.drop(columns=["var_3", "var_10"], inplace=True)
 
     # test init params
-    assert sel.variables is None
     assert sel.threshold == 0.5
     assert sel.cv == 3
     assert sel.scoring == "roc_auc"
     # test fit attrs
-    assert sel.variables_ == [
-        "var_0",
-        "var_1",
-        "var_2",
-        "var_3",
-        "var_4",
-        "var_5",
-        "var_6",
-        "var_7",
-        "var_8",
-        "var_9",
-        "var_10",
-        "var_11",
-    ]
     assert sel.features_to_drop_ == ["var_3", "var_10"]
     assert sel.feature_performance_ == {
         "var_0": 0.5957642619540211,
@@ -241,78 +201,51 @@ def test_automatic_variable_selection(df_test):
     pd.testing.assert_frame_equal(sel.transform(X), Xtransformed)
 
 
-def test_KFold_generators(df_test):
+def test_raises_error_if_evaluating_single_variable_and_threshold_is_None(df_test):
+    X, y = df_test
 
+    sel = SelectBySingleFeaturePerformance(
+        RandomForestClassifier(random_state=1), variables=["var_1"], threshold=None
+    )
+
+    with pytest.raises(ValueError):
+        sel.fit(X, y)
+
+
+def test_test_selector_with_one_variable(df_test):
     X, y = df_test
 
-    # Kfold
     sel = SelectBySingleFeaturePerformance(
         RandomForestClassifier(random_state=1),
+        variables=["var_0"],
         threshold=0.5,
-        cv=KFold(n_splits=3),
     )
     sel.fit(X, y)
-    Xtransformed = sel.transform(X)
 
-    # test fit attrs
-    assert isinstance(sel.features_to_drop_, list)
-    assert all([x for x in sel.features_to_drop_ if x in X.columns])
-    assert len(sel.features_to_drop_) < X.shape[1]
-    assert not Xtransformed.empty
-    assert all([x for x in Xtransformed.columns if x not in sel.features_to_drop_])
-    assert isinstance(sel.feature_performance_, dict)
-    assert all([x for x in X.columns if x in sel.feature_performance_.keys()])
-    assert all(
-        [
-            isinstance(sel.feature_performance_[var], float)
-            for var in sel.feature_performance_.keys()
-        ]
-    )
+    # expected result
+    Xtransformed = X.copy()
+
+    assert sel.features_to_drop_ == []
+    assert sel.feature_performance_ == {
+        "var_0": 0.5957642619540211,
+    }
+    # test transform output
+    pd.testing.assert_frame_equal(sel.transform(X), Xtransformed)
 
-    # Stratfied
     sel = SelectBySingleFeaturePerformance(
         RandomForestClassifier(random_state=1),
+        variables=["var_3"],
         threshold=0.5,
-        cv=StratifiedKFold(n_splits=3),
     )
     sel.fit(X, y)
-    Xtransformed = sel.transform(X)
 
-    # test fit attrs
-    assert isinstance(sel.features_to_drop_, list)
-    assert all([x for x in sel.features_to_drop_ if x in X.columns])
-    assert len(sel.features_to_drop_) < X.shape[1]
-    assert not Xtransformed.empty
-    assert all([x for x in Xtransformed.columns if x not in sel.features_to_drop_])
-    assert isinstance(sel.feature_performance_, dict)
-    assert all([x for x in X.columns if x in sel.feature_performance_.keys()])
-    assert all(
-        [
-            isinstance(sel.feature_performance_[var], float)
-            for var in sel.feature_performance_.keys()
-        ]
-    )
+    # expected result
+    Xtransformed = X.copy()
+    Xtransformed.drop(columns=["var_3"], inplace=True)
 
-    # None
-    sel = SelectBySingleFeaturePerformance(
-        RandomForestClassifier(random_state=1),
-        threshold=0.5,
-        cv=None,
-    )
-    sel.fit(X, y)
-    Xtransformed = sel.transform(X)
-
-    # test fit attrs
-    assert isinstance(sel.features_to_drop_, list)
-    assert all([x for x in sel.features_to_drop_ if x in X.columns])
-    assert len(sel.features_to_drop_) < X.shape[1]
-    assert not Xtransformed.empty
-    assert all([x for x in Xtransformed.columns if x not in sel.features_to_drop_])
-    assert isinstance(sel.feature_performance_, dict)
-    assert all([x for x in X.columns if x in sel.feature_performance_.keys()])
-    assert all(
-        [
-            isinstance(sel.feature_performance_[var], float)
-            for var in sel.feature_performance_.keys()
-        ]
-    )
+    assert sel.features_to_drop_ == ["var_3"]
+    assert sel.feature_performance_ == {
+        "var_3": 0.4752954458526748,
+    }
+    # test transform output
+    pd.testing.assert_frame_equal(sel.transform(X), Xtransformed)
